import importlib



# 导入sann模块的所有包

config = importlib.import_module('SANN.bin.config')
other_utils = importlib.import_module('SANN.bin.other_utils')
data_utils = importlib.import_module('SANN.bin.data_utils')
model_utils = importlib.import_module('SANN.bin.model_utils')


# 定义SANN类
class Sann():
    def __init__(self):
        self.config = config.config
        self.other_utils = other_utils.utils
        self.data_utils = data_utils.utils
        self.model_utils = model_utils.utils

# 实例化sann












import setuptools

with open("README.txt", "r",encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name="jhsp",
    version="0.0.5",
    author="Daye Zhao",
    author_email="zhaozong111@gmail.com",
    description="A package only used by Daye Zhao",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://pypi.org",
    packages = setuptools.find_packages(),
    py_modules = [],
    install_requires=['pandas==1.1.3',
                        'numpy==1.18.5',
                        'tensorflow==2.3.1',
                        'matplotlib==3.3.2',
                        'scikit_learn==0.23.2',
                      ],

)


import os



class Config:
    def __init__(self,cur_path):
        self.cur_path = cur_path
        self.task_name_list = ['不孕症']
        self.task_path_list = [os.path.join(os.path.join(self.cur_path,'data'),task_name) for task_name in self.task_name_list]
        self.model_path = 'model.simple_net'
        self.cross_val_num = 5
        self.epochs_num = 1000
        self.drop_rate = 0.5
        self.random_search_n_iter = 100
        self.random_search_n_jobs = -1
        self.batch_size = 300
        self.model_list = ['SANN','ANN','KNN','SVC','RF']
        self.score_save_path = os.path.join(os.path.join(self.cur_path,'doc'),'score.pkl')
        self.metrics_list = ['accuracy','precision','recall','f1']
        self.random_num = 100
        self.legend_loc = 3
        self.patience_num = 50




config = Config()

if __name__ == '__main__':
    pass